// code based on lp:~pat-mcgowan/+junk/SystemInfo/

import QtQuick 2.0
import QtSystemInfo 5.0
import Ubuntu.Components 0.1
import "components"
import Ubuntu.Components.ListItems 0.1 as ListItem
import QtQuick.XmlListModel 2.0

/*!
    \brief MainView with a Label and Button elements.
*/

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"

    // Note! applicationName needs to match the .desktop filename
    applicationName: "test-network"

    width: units.gu(50)
    height: units.gu(75)

    Tabs {
        Tab {
            anchors.fill: parent
            title: i18n.tr("Network Connectivity")
            Page {
                Column {
                    id: connectivityTextArea
                    spacing: units.gu(1)
                    Text{ text: "Network status: " + getCurrentNetworkStatus() }
                }
            }
        }
        Tab {
            anchors.fill: parent
            title: i18n.tr("Network Info")
            Page {
                Column {
                    id: infoTextArea
                    spacing: units.gu(1)
                    Text{ text: "Network status: " + getCurrentNetworkStatus() }
                    Text{ text: "Network mode: " + getCurrentNetworkMode() }
                    Text{ text: "MAC address: " + network_info.macAddress(network_info.currentNetworkMode,0) }
                    Text{ text: "Network signal strength monitoring: " + isMonitorNetworkSignalStrength() }
                    Text{ text: "Network signal strength: " + network_info.networkSignalStrength(network_info.currentNetworkMode,0) }
                    Text{ text: "Network name: "+ network_info.networkName(network_info.currentNetworkMode,0)}
                    Text{ text: "Cell Id: " + network_info.cellId(0)}
                    Text{ text: "Data technology: "+ getCurrentCellDataTechnology()}
                    Text{id: network_info_text; text: "Network code: "+ network_info.currentMobileNetworkCode(0)}
                    Text{ text: "IMSI: " + network_info.imsi(0)}
                }
            }
        }
    }

    function getCurrentNetworkStatus(){
        switch(network_connectivity_info.networkStatus(network_connectivity_info.currentNetworkMode,0)){
            case NetworkInfo.UnknownStatus: return "The status is unknown or an error occured"
            case NetworkInfo.NoNetworkAvailable: return "There is no network available"
            case NetworkInfo.EmergencyOnly: return "The network only allows emergency calls"
            case NetworkInfo.Searching: return "The device is searching or connecting to the network"
            case NetworkInfo.Busy: return "The network is too busy to be connected"
            case NetworkInfo.Denied: return "The connection to the network has been denied"
            case NetworkInfo.HomeNetwork: return "The device is connected to the home network"
            case NetworkInfo.Roaming: return "The device is connected to some roaming network"
        }
    }

    function getCurrentCellDataTechnology() {
        switch(network_info.currentCellDataTechnology(0))  {
            case NetworkInfo.UnknownDataTechnology: return "Unknown"
            case NetworkInfo.GprsDataTechnology: return "GPRS"
            case NetworkInfo.EdgeDataTechnology: return "EDGE"
            case NetworkInfo.UmtsDataTechnology: return "UMTS"
            case NetworkInfo.HspaDataTechnology: return "HSPA"
       }
    }

    function getCurrentNetworkMode() {
        switch(network_info.currentNetworkMode)
        {
        case  NetworkInfo.UnknownMode: return "The network is unknown or an error occured."
        case  NetworkInfo.GsmModev:  return"Global System for Mobile (GSM) network."
        case  NetworkInfo.CdmaMode:  return "Code Division Multiple Access (CDMA) network."
        case  NetworkInfo.WcdmaMode: return "Wideband Code Division Multiple Access (WCDMA) network."
        case  NetworkInfo.WlanMode: return "Wireless local area network (WLAN) network."
        case  NetworkInfo.EthernetMode: return "Local area network (LAN), or Ethernet network."
        case  NetworkInfo.BluetoothMode: return "Bluetooth network."
        case  NetworkInfo.WimaxMode: return "Worldwide Interoperability for Microwave Access (WiMAX) network."
        case  NetworkInfo.LteMode: return "3GPP Long Term Evolution (LTE) network."
        case  NetworkInfo.TdscdmaMode: return "Time Division Synchronous Code Division Multiple Access (TD-SCDMA) network."
        }
    }

    function isMonitorNetworkSignalStrength() {
       // network_info.
        if (network_info.monitorNetworkSignalStrength)
        {
            return "Yes"
        } else  {
            return "No"
        }
    }

   NetworkInfo {
        id: network_info;
        monitorCurrentNetworkMode: true
        monitorNetworkSignalStrength: true
        monitorNetworkInterfaceCount: true
        monitorNetworkName: true
        monitorNetworkStatus: true
        monitorCellId: true
        monitorCurrentCellDataTechnology: true
        monitorCurrentMobileCountryCode: true
        monitorCurrentMobileNetworkCode: true
        monitorLocationAreaCode: true
    }

   NetworkInfo {
        id: network_connectivity_info;
        monitorCurrentNetworkMode: true
        monitorNetworkSignalStrength: false
        monitorNetworkInterfaceCount: false
        monitorNetworkName: false
        monitorNetworkStatus: false
        monitorCellId: false
        monitorCurrentCellDataTechnology: false
        monitorCurrentMobileCountryCode: false
        monitorCurrentMobileNetworkCode: false
        monitorLocationAreaCode: false
    }

}
